@@ -33,6 +33,7 @@ EncodeFileImp::EncodeFileImp(QWidget* parent,
   // Specify to only accept wav files
   file->setFilter("*.wav|Wav Files");
 
+  connect(file,SIGNAL(textChanged(const QString &)),this,SLOT(enableEncodeButton(const QString &)));
   connect(encodeButton,SIGNAL(clicked()),this,SLOT(encode()));
 }
 
@@ -61,6 +62,8 @@ void EncodeFileImp::encode(){
   newJob->track_artist = track_artist->text();
   newJob->track_comment = track_comment->text();
 
+  newJob->removeTempFile = false;
+
   emit(startJob(newJob));
 
   // Same message and *strings* from tracksimp.cpp
@@ -71,5 +74,9 @@ void EncodeFileImp::encode(){
  i18n("Jobs have started"), i18n("Jobs have started"));
 }
 
+void EncodeFileImp::enableEncodeButton(const QString &text){
+  encodeButton->setEnabled(!text.isEmpty());
+}
+
 
 #include "encodefileimp.moc"
