@@ -43,7 +43,7 @@ Encoder::Encoder( QObject* parent, const char* name):QObject(parent,name),report
 
 /**
  * Load the settings for this class.
- */ 
+ */
 void Encoder::loadSettings() {
 	loadEncoder(Prefs::currentEncoder());
 	// If the cpu count change then try
@@ -51,13 +51,16 @@ void Encoder::loadSettings() {
 		tendToNewJobs();
 }
 
-void Encoder::loadEncoder( int encoder ){
+EncoderPrefs* Encoder::loadEncoder( int encoder ){
+	EncoderPrefs* prefs;
 	QString currentEncoderGroup = QString("Encoder_%1").arg(encoder);
 	prefs = EncoderPrefs::prefs(currentEncoderGroup);
 	if ( !EncoderPrefs::hasPrefs(currentEncoderGroup) ) {
 		KMessageBox::sorry(0, i18n("No encoder has been selected.\nPlease select an encoder in the configuration."), i18n("No Encoder Selected"));
 		prefs->setCommandLine(QString::null);
-	}				
+	}
+
+	return prefs;
 }
 
 /**
@@ -86,7 +89,7 @@ int Encoder::activeJobCount() {
 	return jobs.count();
 }
 
-/** 
+/**
  * @return The number of pending jobs
  */
 int Encoder::pendingJobCount() {
@@ -129,7 +132,8 @@ void Encoder::removeJob(int id ) {
  * @param job the job to encode.
  */
 void Encoder::encodeWav(Job *job ) {
-	emit(addJob(job, i18n("Encoding (%1): %2 - %3").arg(prefs->extension()).arg(job->track_artist).arg(job->track_title)));
+	emit(addJob(job, i18n("Encoding (%1): %2 - %3").arg(loadEncoder(job->encoder)->extension())
+		                                             .arg(job->track_artist).arg(job->track_title)));
 	pendingJobs.append(job);
 	tendToNewJobs();
 }
@@ -153,12 +157,10 @@ void Encoder::tendToNewJobs() {
 	Job *job = pendingJobs.first();
 	pendingJobs.remove(job);
 	
-	// if encoder is selected load it.
-	if ( job->encoder != -1 ){
-		loadEncoder(job->encoder);
-	}
+	EncoderPrefs* prefs = loadEncoder(job->encoder);
 	
 	QString desiredFile = Prefs::fileFormat();
+	desiredFile.replace( QRegExp("~"), QDir::homeDirPath() );
 	{
 		QMap <QString,QString> map;
 		map.insert("extension", prefs->extension());
@@ -167,7 +169,6 @@ void Encoder::tendToNewJobs() {
 		jobx.fix("/", "%2f");
 		// If the user wants anything regexp replaced do it now...
 		desiredFile = jobx.replaceSpecialChars(desiredFile, false, map);
-		desiredFile.replace( QRegExp("~"), QDir::homeDirPath() );
 	}
 
 	while ( QFile::exists( desiredFile ) ) {
@@ -186,7 +187,7 @@ void Encoder::tendToNewJobs() {
 	
 	int lastSlash = desiredFile.findRev('/',-1);
 	if ( lastSlash == -1 ||
-			!(KStandardDirs::makeDir( desiredFile.mid(0,lastSlash))) ) {
+			!(KStandardDirs::makeDir( desiredFile.mid(0,lastSlash), 0775)) ) {
 		KMessageBox::sorry(0, i18n("Cannot place file, unable to make directories."), i18n("Encoding Failed"));
 		emit jobsChanged();
 		updateProgress(job->id, -1);
@@ -234,11 +235,12 @@ void Encoder::receivedThreadOutput(KProcess *process, char *buffer, int length )
 		kdDebug(60002) << buffer << endl;
 	
 	// Make sure we have a job to send an update too.
-	Job *job = jobs[(KShellProcess*)process];
-	if ( !job ) {
+	if(jobs.find((KShellProcess*)process) == jobs.end()){
 		kdDebug(60002) << "Encoder::receivedThreadOutput Job doesn't exists. Line: " <<  __LINE__ << endl;
 		return;
 	}
+	
+	Job *job = jobs[(KShellProcess*)process];
 
 	// Keep the output in the event it fails.
 	job->output += QString(buffer).mid(0,length); 
@@ -251,7 +253,7 @@ void Encoder::receivedThreadOutput(KProcess *process, char *buffer, int length )
 		return;
 	}
 	//qDebug(QString("Pre cropped: %1").arg(output).latin1());
-	output = output.mid(output.find('%')-prefs->percentLength(),2);
+	output = output.mid(output.find('%')-loadEncoder(job->encoder)->percentLength(),2);
 	//qDebug(QString("Post cropped: %1").arg(output).latin1());
 	bool conversionSuccessfull = false;
 	int percent = output.toInt(&conversionSuccessfull);
@@ -283,21 +285,17 @@ void Encoder::jobDone(KProcess *process ) {
 	bool showDebugBox = false;
 	if ( process->exitStatus() == 127 ) {
 		KMessageBox::sorry(0, i18n("The selected encoder was not found.\nThe wav file has been removed. Command was: %1").arg(job->errorString), i18n("Encoding Failed"));
-		QFile::remove(job->location);
 		emit(updateProgress(job->id, -1));
 	}
 	else if ( QFile::exists(job->newLocation) ) {
-		emit(jobIsDone(job, prefs->extension()));
-		QFile::remove(job->location);
-
 		// fyi segfaults return 136
 		if ( process->exitStatus() != 0 ) {
-			if ( KMessageBox::questionYesNo(0, i18n("The encoder exited with a error.  Please check that the file was created.\nDo you want to see the full encoder output?"), i18n("Encoding Failed")) == KMessageBox::Yes )
+			if ( KMessageBox::questionYesNo(0, i18n("The encoder exited with a error.  Please check that the file was created.\nDo you want to see the full encoder output?"), i18n("Encoding Failed"),i18n("Show Output"),i18n("Skip Output")) == KMessageBox::Yes )
 			{
 				showDebugBox = true;
 			}
 		}
-		else{ 
+		else{
 			//qDebug("Must be done: %d", (process->exitStatus()));
 			emit(updateProgress(job->id, 100));
 			KNotifyClient::event("track encoded");
@@ -307,14 +305,16 @@ void Encoder::jobDone(KProcess *process ) {
 	}
 	else
 	{
-		if ( KMessageBox::questionYesNo(0, i18n("The encoded file was not created.\nPlease check the encoder options.\nThe wav file has been removed.\nDo you want to see the full encoder output?"), i18n("Encoding Failed")) == KMessageBox::Yes )
+		if ( KMessageBox::questionYesNo(0, i18n("The encoded file was not created.\nPlease check the encoder options.\nThe wav file has been removed.\nDo you want to see the full encoder output?"), i18n("Encoding Failed"),i18n("Show Output"),i18n("Skip Output")) == KMessageBox::Yes )
 		{
 			showDebugBox = true;
 		}
-		QFile::remove( job->location );
 		emit( updateProgress( job->id, -1 ) );
 	}
 
+	if ( job->removeTempFile )
+		QFile::remove( job->location );
+
 	if( showDebugBox ){
 		EncoderOutput dlg( 0, "Encoder Output" );
 		job->output = job->errorString + "\n\n\n" + job->output;
