@@ -41,11 +41,15 @@ int main(int argc, char *argv[]){
   KCmdLineArgs::addCmdLineOptions( options );
   KApplication a(argc, argv);
   KAudioCreator *app = new KAudioCreator(0, "MainWindow");
+
+  // we need some strings from libkcddb for the cddb album dialog
+  KGlobal::locale()->insertCatalogue("libkcddb");
+
   a.setMainWidget(app);
 
   KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
   if ( args->count()>0 ) app->setDevice( args->arg( 0 ) );
-
+  args->clear();
   app->show();
   return a.exec();
 }
