@@ -26,6 +26,8 @@
 #include <ktempfile.h>
 #include <kmessagebox.h>
 #include <knotifyclient.h>
+#include <kstandarddirs.h>
+#include <kio/scheduler.h>
 
 /**
  * Constructor, load settings.
@@ -51,11 +53,10 @@ Ripper::~Ripper(){
 	for( it = jobs.begin(); it != jobs.end(); ++it ){
 		 KIO::Job* ioJob = it.key();
 		Job *job = it.data();
-		if(job){
-			delete job;
-		}
+		delete job;
+	
 		if(ioJob){
-			KIO::FileCopyJob *copyJob = dynamic_cast<KIO::FileCopyJob*> (ioJob);
+			KIO::FileCopyJob *copyJob = static_cast<KIO::FileCopyJob*> (ioJob);
 			disconnect(copyJob, SIGNAL(result(KIO::Job*)), this, SLOT(copyJobResult(KIO::Job*)));
 			disconnect(copyJob, SIGNAL(percent ( KIO::Job *, unsigned long)), this, SLOT(updateProgress ( KIO::Job *, unsigned long)));
 			QString fileDestination = (copyJob->destURL()).path();
@@ -91,7 +92,6 @@ void Ripper::removeJob(int id){
 	QMap<KIO::Job*, Job*>::Iterator it;
 	for( it = jobs.begin(); it != jobs.end(); ++it ){
 		if(it.data()->id == id){
-			jobs.remove(it.key());
 			KIO::FileCopyJob *copyJob = dynamic_cast<KIO::FileCopyJob*> (it.key());
 			if(copyJob){
 				QString fileDestination = (copyJob->destURL()).path();
@@ -106,6 +106,7 @@ void Ripper::removeJob(int id){
 					f.remove();
 				}
 			}
+			jobs.remove(it.key());
 			break;
 		}
 	}
@@ -161,6 +162,10 @@ void Ripper::tendToNewJobs(){
 	QString defaultTempDir;
 	if(Prefs::enableTempDir())
 		defaultTempDir = Prefs::tempDir();
+	else
+		defaultTempDir = locateLocal("tmp", "");
+	// For cases like "/tmp" where there is a missing /
+	defaultTempDir = KURL(defaultTempDir).path(1);
 	KTempFile tmp( defaultTempDir, ".wav" );
 	tmp.setAutoDelete(true);
 
@@ -177,10 +182,11 @@ void Ripper::tendToNewJobs(){
 	KURL source(wavFile);
 	KURL dest(tmp.name());
 
-	KIO::FileCopyJob *copyJob = new KIO::FileCopyJob(source, dest, 0644, FALSE, TRUE, FALSE, FALSE);
+	KIO::FileCopyJob *copyJob = new KIO::FileCopyJob(source, dest, 0644, false, true, false, false);
+	jobs.insert(copyJob, job);
 	connect(copyJob, SIGNAL(result(KIO::Job*)), this, SLOT(copyJobResult(KIO::Job*)));
 	connect(copyJob, SIGNAL(percent ( KIO::Job *, unsigned long)), this, SLOT(updateProgress ( KIO::Job *, unsigned long)));
-	jobs.insert(copyJob, job);
+	
 	emit jobsChanged();
 }
 
@@ -194,10 +200,10 @@ void Ripper::copyJobResult(KIO::Job *copyjob){
 		return;
 	KIO::FileCopyJob *copyJob = dynamic_cast<KIO::FileCopyJob*> (copyjob);
 	KNotifyClient::event("track ripped");
-	
-	Job *newJob = jobs[copyjob];
-	if(!newJob)
+
+	if(jobs.find(copyjob) == jobs.end())
 		return;
+	Job *newJob = jobs[copyjob];
 	jobs.remove(copyjob);
 
 	if(Prefs::beepAfterRip())
@@ -214,9 +220,10 @@ void Ripper::copyJobResult(KIO::Job *copyjob){
 		file.remove();
 		emit updateProgress(newJob->id, -1);
 		delete newJob;
+		newJob = 0;
 	}
 
-	if(newJob->lastSongInAlbum){
+	if(newJob && newJob->lastSongInAlbum){
 		if(Prefs::autoEjectAfterRip()){
 			// Don't eject device if a pending job has that device
 			Job *job = pendingJobs.first();
