@@ -1,7 +1,7 @@
 #ifndef SMTPSUBMIT_H
 #define SMTPSUBMIT_H
 /*
-  Copyright (C) 2003 Richard Lrkng <nouseforaname@home.se>
+  Copyright (C) 2003 Richard Lärkäng <nouseforaname@home.se>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -31,8 +31,9 @@ namespace KCDDB
       virtual ~SMTPSubmit();
 
     protected:
-      void initURL( const QString&, uint, const QString&);
-      void makeURL( const QString & );
+      virtual void makeDiskData( const CDInfo&, const TrackOffsetList& );
+
+      virtual KIO::Job* createJob(const CDInfo& cdInfo);
 
       KURL url_;
       QString from_, to_;
