@@ -16,6 +16,7 @@
 #define __MPGPLUGIN_H
 
 #include "../decoder/decoderPlugin.h"
+#include <kdemacros.h>
 
 #define _INSERT_NO            0
 #define _INSERT_VIDEO         1
@@ -27,7 +28,7 @@ class MpegSystemStream;
 class MpegStreamPlayer;
 class MpegVideoLength;
 
-class MpgPlugin : public DecoderPlugin {
+class KDE_EXPORT MpgPlugin : public DecoderPlugin {
 
   MpegSystemHeader* mpegSystemHeader;
   MpegSystemStream* mpegSystemStream;
