@@ -1,5 +1,5 @@
 /*
- * $Id: mpg123PlayObject_impl.cpp,v 1.22.2.1 2001/08/23 18:05:46 waba Exp $
+ * $Id: mpg123PlayObject_impl.cpp 212185 2003-03-07 22:11:39Z waba $
  * Copyright (C) 2001 Kevin Puetz
  *
  *
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -288,7 +288,7 @@ mpg123PlayObject_impl::mpg123PlayObject_impl()
 	//memset(&mp->fr, 0, sizeof(struct frame)); XXX: why would I need to do this?
 
 	prgName = strdup("arts/mpg123");
-	prgVersion = strdup("$Revision: 1.22.2.1 $");
+	prgVersion = strdup("$Revision: 212185 $");
 	pcm_point = 0;
 	pcm_sample=pcm_buf; // just point this to our internal buffer
 	memset(&param, 0, sizeof(struct parameter));
@@ -536,7 +536,7 @@ poCapabilities mpg123PlayObject_impl::capabilities()
 //YYY
 string mpg123PlayObject_impl::mediaName()
 {
-	return "";
+	return param.filename;
 }
 
 poState mpg123PlayObject_impl::state()
